################
ChatBoostRemoved
################


.. automodule:: litegram.types.chat_boost_removed
    :members:
    :member-order: bysource
    :undoc-members: True
    :exclude-members: model_config,model_fields
